Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r76000 - in sandbox/closure/boost/closure/aux_/preprocessor/traits: . decl_ decl_sign_ parse_params_ parsed_params_
From: lorcaminiti_at_[hidden]
Date: 2011-12-16 13:56:16


Author: lcaminiti
Date: 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
New Revision: 76000
URL: http://svn.boost.org/trac/boost/changeset/76000

Log:
Renaming pp-traits.
Added:
   sandbox/closure/boost/closure/aux_/preprocessor/traits/bind.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_/
      - copied from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/parsed_params_/
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_any_bind.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_bind.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_const_bind.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_error.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_params.hpp
      - copied, changed from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_sign_/
      - copied from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params_/
Removed:
   sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp
   sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params_/
   sandbox/closure/boost/closure/aux_/preprocessor/traits/parsed_params_/
Text files modified:
   sandbox/closure/boost/closure/aux_/preprocessor/traits/bind.hpp | 54 +++++++++++------------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl.hpp | 37 +++++++---------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_any_bind.hpp | 51 ++++++++++++----------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_bind.hpp | 58 ++++++++++++-------------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_const_bind.hpp | 63 +++++++++++++++-------------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_error.hpp | 31 +++++++------
   sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_params.hpp | 87 +++++++++++++++++++--------------------
   7 files changed, 191 insertions(+), 190 deletions(-)

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/bind.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,48 +4,46 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_BIND_TRAITS_HPP_
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_HPP_
 
 #include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/logical/not.hpp>
+#include <boost/preprocessor/logical/compl.hpp>
 #include <boost/preprocessor/facilities/is_empty.hpp>
 
 // PRIVATE //
 
-// Not-this bind is 2-tuple `(name_without_type, name_with_type)`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITHOUT_TYPE_ 0
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITH_TYPE_ 1
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_ 2
+// Non-this bind is 2-tuple `(name_without_type, name_with_type)`.
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_WITHOUT_TYPE_ 0
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_WITH_TYPE_ 1
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_MAX_ 2
 
 // PUBLIC //
 
-// Bind not-this (const or not).
+// Bind non-this (const or not).
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE(any_bind) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITHOUT_TYPE_, \
- any_bind)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE(any_bind) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITH_TYPE_, \
- any_bind)(/* expand empty */)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HAS_TYPE(any_bind) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE(any_bind)))
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_WITHOUT_TYPE(bind_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_MAX_, \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_WITHOUT_TYPE_, bind_traits)
+
+// Could be empty (if no type was explicitly specified).
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_WITH_TYPE(bind_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_MAX_, \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_INDEX_WITH_TYPE_, bind_traits) \
+ (/* expand EMPTY */)
+
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_HAVE_TYPE(bind_traits) \
+ BOOST_PP_COMPL(BOOST_PP_IS_EMPTY( \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_WITH_TYPE(any_bind)))
 
 // Bind this (const or not).
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_TYPE(any_bind_this_type) \
- BOOST_PP_TUPLE_ELEM(1, 0, any_bind_this_type)(/* expand empty */)
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_THIS_TYPE(bind_this_type) \
+ BOOST_PP_TUPLE_ELEM(1, 0, bind_this_type)(/* expand EMPTY */)
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_HAS_TYPE( \
- any_bind_this_type) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_TYPE( \
- any_bind_this_type)))
+#define BOOST_CLOSURE_AUX_PP_BIND_TRAITS_THIS_HAS_TYPE(bind_this_type) \
+ BOOST_PP_COMPL(BOOST_PP_IS_EMPTY( \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_THIS_TYPE(bind_this_type)))
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_any_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,54 +4,59 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_ANY_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_ANY_BIND_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ANY_BIND_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ANY_BIND_HPP_
 
-#include "params_const_bind.hpp"
-#include "params_bind.hpp"
+#include <boost/closure/aux_/preprocessor/traits/decl_const_bind.hpp>
+#include <boost/closure/aux_/preprocessor/traits/decl_bind.hpp>
 #include <boost/preprocessor/logical/bitor.hpp>
 #include <boost/preprocessor/control/iif.hpp>
 #include <boost/preprocessor/tuple/eat.hpp>
 #include <boost/preprocessor/list/append.hpp>
 
 // Expand to 1 iff `this` is bound (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND_THIS(params) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_ANY_BIND_THIS(decl_traits) \
     /* can't use PP_BITOR/PP_OR because don't expand on MSVC */ \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS(params), \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_CONST_BIND_THIS( \
+ decl_traits), \
         1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params), \
+ , BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_BIND_THIS( \
+ decl_traits), \
         1 \
     , \
         0 \
     ))
 
 // Expand to 1 iff has one or more bound including `this` (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND(params) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_ANY_BIND(decl_traits) \
     /* can't use PP_BITOR/PP_OR because don't expand on MSVC */ \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND(params), \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_CONST_BIND( \
+ decl_traits), \
         1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS( \
- params), \
+ , BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_CONST_BIND_THIS( \
+ decl_traits), \
         1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND(params), \
+ , BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_BIND(decl_traits), \
         1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params), \
+ , BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_BIND_THIS( \
+ decl_traits), \
         1 \
     , \
         0 \
     ))))
 
 // Expand to list with all binds (const or not) but excluding `this`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND_WITHOUT_THIS(params) \
- BOOST_PP_LIST_APPEND(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ALL_BIND_WITHOUT_THIS(decl_traits) \
+ BOOST_PP_LIST_APPEND(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND( \
+ decl_traits), BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND(decl_traits))
 
 // Expand to list with all binds (const or not) and including `this` if bound
 // (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND(params) \
- BOOST_PP_LIST_APPEND(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND(params), \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND_THIS( \
- params), \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ALL_BIND(decl_traits) \
+ BOOST_PP_LIST_APPEND(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ALL_BIND( \
+ decl_traits), \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_ANY_BIND_THIS( \
+ decl_traits), \
             (this, BOOST_PP_NIL) /* `this` never by ref because in C++ */ \
         , \
             BOOST_PP_NIL \
@@ -60,10 +65,10 @@
 
 // Expand to list of all `this` types (const or not). There is at most 1 bind
 // `this` type if no parsing error.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND_THIS_TYPE(params) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ALL_BIND_THIS_TYPE(decl_traits) \
     BOOST_PP_LIST_APPEND( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(params))
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_THIS_TYPE(decl_traits), \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_THIS_TYPE(decl_traits))
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_bind.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,48 +4,46 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_HPP_
 
-#include "param_any_bind.hpp"
-#include "parsed_params_/index.hpp"
+#include <boost/closure/aux_/preprocessor/traits/param_any_bind.hpp>
+#include <boost/closure/aux_/preprocessor/traits/params_/index.hpp>
 #include <boost/preprocessor/tuple/elem.hpp>
 #include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
 #include <boost/preprocessor/list/transform.hpp>
 
 // PRIVATE //
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_(d, macro, elem) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_TYPED_(d, macro, elem) \
     macro(elem)
 
 // PUBLIC //
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_BIND, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_WITHOUT_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_BIND, decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_BIND(decl_traits) \
+ BOOST_PP_LIST_IS_CONS(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND(decl_traits))
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_WITHOUT_TYPE(decl_traits) \
+ BOOST_PP_LIST_TRANSFORM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_TYPED_, \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_WITHOUT_TYPE, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND(params))
         
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_WITH_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_BIND_THIS_TYPE, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE( \
- params))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_WITH_TYPE(decl_traits) \
+ BOOST_PP_LIST_TRANSFORM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_TYPED_, \
+ BOOST_CLOSURE_AUX_PP_BIND_TRAITS_WITH_TYPE, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND(decl_traits))
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_THIS_TYPE(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_BIND_THIS_TYPE, decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_BIND_THIS(decl_traits) \
+ BOOST_PP_LIST_IS_CONS(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_BIND_THIS_TYPE( \
+ decl_traits))
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_const_bind.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_const_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,48 +4,51 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_HPP_
 
-#include "param_any_bind.hpp"
-#include "parsed_params_/index.hpp"
+#include <boost/closure/aux_/preprocessor/traits/bind.hpp>
+#include <boost/closure/aux_/preprocessor/traits/decl_/index.hpp>
 #include <boost/preprocessor/tuple/elem.hpp>
 #include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
 #include <boost/preprocessor/list/transform.hpp>
 
 // PRIVATE //
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_(d, macro, elem) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_TYPED_(d, macro, elem) \
     macro(elem)
 
 // PUBLIC //
 
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_CONST_BIND, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_WITHOUT_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_CONST_BIND, decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_CONST_BIND(decl_traits) \
+ BOOST_PP_LIST_IS_CONS(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND( \
+ decl_traits))
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_WITHOUT_TYPE( \
+ decl_traits) \
+ BOOST_PP_LIST_TRANSFORM( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAUTS_CONST_BIND_TYPED_, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ANY_BIND_WITHOUT_TYPE, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND(decl_traits))
         
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_WITH_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_CONST_BIND_THIS_TYPE, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(\
- params))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_WITH_TYPE(decl_traits) \
+ BOOST_PP_LIST_TRANSFORM( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_TYPED_, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ANY_BIND_WITH_TYPE, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND(decl_traits))
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_THIS_TYPE(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRIATS_INDEX_CONST_BIND_THIS_TYPE, \
+ decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_CONST_BIND_THIS(params) \
+ BOOST_PP_LIST_IS_CONS( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_CONST_BIND_THIS_TYPE(decl_traits))
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_error.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_error.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,26 +4,27 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR_HPP_
 
-#include "parsed_params_/index.hpp"
+#include <boost/closure/aux_/preprocessor/traits/decl_/index.hpp>
 #include <boost/preprocessor/tuple/elem.hpp>
 #include <boost/preprocessor/facilities/is_empty.hpp>
-#include <boost/preprocessor/logical/not.hpp>
+#include <boost/preprocessor/logical/compl.hpp>
+
+// PUBLIC //
 
 // Expand to `EMPTY` if no error, to `ERROR_message_text EMPTY` otherwise.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_ERROR, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_MSG(params) \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR(params)(/* expand empty */)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ERROR(params) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_MSG( \
- params)))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_ERROR, decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR_MSG(decl_traits) \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR(decl_traits)(/* expand EMPTY */)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_ERROR(decl_traits) \
+ BOOST_PP_COMPL(BOOST_PP_IS_EMPTY( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_ERROR_MSG(decl_traits)))
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_params.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp)
==============================================================================
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_params.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,82 +4,81 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_HPP_
 
-#include "parsed_params_/index.hpp"
-#include <boost/detail/preprocessor/keyword/default.hpp>
+#include <boost/closure/aux_/preprocessor/traits/decl_/index.hpp>
+#include <boost/closure/detail/preprocessor/keyword/default.hpp>
 #include <boost/preprocessor/tuple/elem.hpp>
+#include <boost/preprocessor/tuple/eat.hpp>
 #include <boost/preprocessor/arithmetic/inc.hpp>
 #include <boost/preprocessor/control/iif.hpp>
-#include <boost/preprocessor/logical/not.hpp>
+#include <boost/preprocessor/logical/compl.hpp>
+#include <boost/preprocessor/facilities/is_empty.hpp>
 #include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
 #include <boost/preprocessor/list/fold_left.hpp>
 
 // PRIVATE //
 
 // Param 2-tuple `([auto | register] type name, default_value)`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DECL_ 0
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DEFAULT_ 1
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_ 2
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_OP_(s, \
- defaults_count, param) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_HAS_DEFAULT( \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_DECL_ 0
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_DEFAULT_ 1
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_MAX_ 2
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_COUNT_DEFAULTS_OP_(s, \
+ default_count, param) \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_HAS_DEFAULT( \
             param), \
         BOOST_PP_INC \
     , \
- defaults_count BOOST_PP_TUPLE_EAT(1) \
- )(defaults_count)
+ default_count BOOST_PP_TUPLE_EAT(1) \
+ )(default_count)
 
 // Precondition: unbinds is a pp-list which is not nil.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_(unbinds) \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_COUNT_DEFAULTS_(params) \
     BOOST_PP_LIST_FOLD_LEFT( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_OP_, \
- 0 /* start with defaults_count to 0 */, \
- unbinds)
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_COUNT_DEFAULTS_OP_, \
+ 0 /* start with defaults_count to 0 */, params)
 
 // Expand to `default ... EMPTY()` if default value, `EMPTY()` otherwise.
 // Leading default is kept because default value might not be alphanumeric
 // (so failing `CAT` for `IS_EMPTY` check).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param) \
- BOOST_PP_TUPLE_ELEM( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DEFAULT_, param) \
- (/* expand empty */)
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_DEFAULT_(param) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_MAX_, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_DEFAULT_, param) \
+ (/* expand EMPTY */)
 
 // PUBLIC //
 
 // Expand to param declaration: [auto | register] type name.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DECL(param) \
- BOOST_PP_TUPLE_ELEM( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DECL_, param)
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_DECL(param) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_MAX_, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_INDEX_DECL_, param)
 
 // Expand to param default value (empty if none).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT(param) \
- BOOST_DETAIL_PP_KEYWORD_DEFAULT_REMOVE_FRONT( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_DEFAULT(param) \
+ BOOST_CLOSURE_DETAIL_PP_KEYWORD_DEFAULT_REMOVE_FRONT( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_DEFAULT_(param))
 
 // Expand to 1 if param has default value, 0 otherwise.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_HAS_DEFAULT(param) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param)))
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_HAS_DEFAULT(param) \
+ BOOST_PP_COMPL(BOOST_PP_IS_EMPTY( \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAM_DEFAULT_(param)))
 
 // Expand to pp-list of ALL unbind params.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_UNBIND, params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_UNBIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS(params) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_UNBIND(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_ \
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS(decl_traits) \
+ BOOST_PP_TUPLE_ELEM(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_MAX, \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_INDEX_PARAMS, decl_traits)
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_PARAMS(decl_traits) \
+ BOOST_PP_LIST_IS_CONS(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS(decl_traits))
+
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_COUNT_DEFAULTS(decl_traits) \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HAVE_PARAMS(decl_traits), \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS_COUNT_DEFAULTS_ \
     , \
         0 BOOST_PP_TUPLE_EAT(1) \
- )(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params))
+ )(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_PARAMS(decl_traits))
 
 #endif // #include guard
 

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/param_any_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,51 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HPP_
-
-#include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/logical/not.hpp>
-#include <boost/preprocessor/facilities/is_empty.hpp>
-
-// PRIVATE //
-
-// Not-this bind is 2-tuple `(name_without_type, name_with_type)`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITHOUT_TYPE_ 0
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITH_TYPE_ 1
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_ 2
-
-// PUBLIC //
-
-// Bind not-this (const or not).
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE(any_bind) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITHOUT_TYPE_, \
- any_bind)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE(any_bind) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_INDEX_WITH_TYPE_, \
- any_bind)(/* expand empty */)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_HAS_TYPE(any_bind) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE(any_bind)))
-
-// Bind this (const or not).
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_TYPE(any_bind_this_type) \
- BOOST_PP_TUPLE_ELEM(1, 0, any_bind_this_type)(/* expand empty */)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_HAS_TYPE( \
- any_bind_this_type) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_THIS_TYPE( \
- any_bind_this_type)))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,69 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_ANY_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_ANY_BIND_HPP_
-
-#include "params_const_bind.hpp"
-#include "params_bind.hpp"
-#include <boost/preprocessor/logical/bitor.hpp>
-#include <boost/preprocessor/control/iif.hpp>
-#include <boost/preprocessor/tuple/eat.hpp>
-#include <boost/preprocessor/list/append.hpp>
-
-// Expand to 1 iff `this` is bound (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND_THIS(params) \
- /* can't use PP_BITOR/PP_OR because don't expand on MSVC */ \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS(params), \
- 1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params), \
- 1 \
- , \
- 0 \
- ))
-
-// Expand to 1 iff has one or more bound including `this` (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND(params) \
- /* can't use PP_BITOR/PP_OR because don't expand on MSVC */ \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND(params), \
- 1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS( \
- params), \
- 1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND(params), \
- 1 \
- , BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params), \
- 1 \
- , \
- 0 \
- ))))
-
-// Expand to list with all binds (const or not) but excluding `this`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND_WITHOUT_THIS(params) \
- BOOST_PP_LIST_APPEND(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-// Expand to list with all binds (const or not) and including `this` if bound
-// (const or not).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND(params) \
- BOOST_PP_LIST_APPEND(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND(params), \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ANY_BIND_THIS( \
- params), \
- (this, BOOST_PP_NIL) /* `this` never by ref because in C++ */ \
- , \
- BOOST_PP_NIL \
- ) \
- )
-
-// Expand to list of all `this` types (const or not). There is at most 1 bind
-// `this` type if no parsing error.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ALL_BIND_THIS_TYPE(params) \
- BOOST_PP_LIST_APPEND( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(params))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/params_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,51 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_HPP_
-
-#include "param_any_bind.hpp"
-#include "parsed_params_/index.hpp"
-#include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
-#include <boost/preprocessor/list/transform.hpp>
-
-// PRIVATE //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_(d, macro, elem) \
- macro(elem)
-
-// PUBLIC //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_BIND, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_WITHOUT_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_WITH_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_BIND_THIS_TYPE, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_BIND_THIS(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_BIND_THIS_TYPE( \
- params))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/params_const_bind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,51 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_HPP_
-
-#include "param_any_bind.hpp"
-#include "parsed_params_/index.hpp"
-#include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
-#include <boost/preprocessor/list/transform.hpp>
-
-// PRIVATE //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_(d, macro, elem) \
- macro(elem)
-
-// PUBLIC //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_CONST_BIND, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_WITHOUT_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITHOUT_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_WITH_TYPE(params) \
- BOOST_PP_LIST_TRANSFORM(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_TYPED_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAM_ANY_BIND_WITH_TYPE, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_CONST_BIND_THIS_TYPE, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_CONST_BIND_THIS(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_CONST_BIND_THIS_TYPE(\
- params))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/params_error.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,29 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_HPP_
-
-#include "parsed_params_/index.hpp"
-#include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/facilities/is_empty.hpp>
-#include <boost/preprocessor/logical/not.hpp>
-
-// Expand to `EMPTY` if no error, to `ERROR_message_text EMPTY` otherwise.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_ERROR, \
- params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_MSG(params) \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR(params)(/* expand empty */)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_ERROR(params) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_ERROR_MSG( \
- params)))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/params_unbind.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,85 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_HPP_
-
-#include "parsed_params_/index.hpp"
-#include <boost/detail/preprocessor/keyword/default.hpp>
-#include <boost/preprocessor/tuple/elem.hpp>
-#include <boost/preprocessor/arithmetic/inc.hpp>
-#include <boost/preprocessor/control/iif.hpp>
-#include <boost/preprocessor/logical/not.hpp>
-#include <boost/preprocessor/list/adt.hpp> // For `IS_CONS`.
-#include <boost/preprocessor/list/fold_left.hpp>
-
-// PRIVATE //
-
-// Param 2-tuple `([auto | register] type name, default_value)`.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DECL_ 0
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DEFAULT_ 1
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_ 2
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_OP_(s, \
- defaults_count, param) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_HAS_DEFAULT( \
- param), \
- BOOST_PP_INC \
- , \
- defaults_count BOOST_PP_TUPLE_EAT(1) \
- )(defaults_count)
-
-// Precondition: unbinds is a pp-list which is not nil.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_(unbinds) \
- BOOST_PP_LIST_FOLD_LEFT( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_OP_, \
- 0 /* start with defaults_count to 0 */, \
- unbinds)
-
-// Expand to `default ... EMPTY()` if default value, `EMPTY()` otherwise.
-// Leading default is kept because default value might not be alphanumeric
-// (so failing `CAT` for `IS_EMPTY` check).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param) \
- BOOST_PP_TUPLE_ELEM( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DEFAULT_, param) \
- (/* expand empty */)
-
-// PUBLIC //
-
-// Expand to param declaration: [auto | register] type name.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DECL(param) \
- BOOST_PP_TUPLE_ELEM( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_MAX_, \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_INDEX_DECL_, param)
-
-// Expand to param default value (empty if none).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT(param) \
- BOOST_DETAIL_PP_KEYWORD_DEFAULT_REMOVE_FRONT( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param))
-
-// Expand to 1 if param has default value, 0 otherwise.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_HAS_DEFAULT(param) \
- BOOST_PP_NOT(BOOST_PP_IS_EMPTY( \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_PARAM_DEFAULT_(param)))
-
-// Expand to pp-list of ALL unbind params.
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params) \
- BOOST_PP_TUPLE_ELEM(BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_MAX, \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_INDEX_UNBIND, params)
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_UNBIND(params) \
- BOOST_PP_LIST_IS_CONS(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params))
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS(params) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_HAVE_UNBIND(params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND_COUNT_DEFAULTS_ \
- , \
- 0 BOOST_PP_TUPLE_EAT(1) \
- )(BOOST_LOCAL_AUX_PP_SIGN_PARAMS_UNBIND(params))
-
-#endif // #include guard
-

Deleted: sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp
==============================================================================
--- sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
+++ (empty file)
@@ -1,35 +0,0 @@
-
-// Copyright (C) 2009-2011 Lorenzo Caminiti
-// Use, modification, and distribution is subject to the Boost Software
-// License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
-// copy at http://www.boost.org/LICENSE_1_0.txt).
-
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_HPP_
-
-#include "parse_params_/is_void.hpp"
-#include "parse_params_/seq.hpp"
-#include "parsed_params_/nil.hpp"
-#include <boost/preprocessor/control/iif.hpp>
-
-// PRIVATE //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_NONE_(unused) \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_NIL
-
-// PUBLIC //
-
-// parenthesized_params: Empty ``, or `void`, or `(void)` for no params
-// Or, `{([auto | register] param_type param_name)[(default default_value)]
-// | ([const] bind [&] bind_name}+` where `bind_name` can be `this` (but not
-// `&this` as usual in C++).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS(parenthesized_params) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_IS_VOID( \
- parenthesized_params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_NONE_ \
- , \
- BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_SEQ \
- )(parenthesized_params)
-
-#endif // #include guard
-


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- /sandbox/closure/boost/closure/aux_/preprocessor/traits/parse_params.hpp (original)
+++ sandbox/closure/boost/closure/aux_/preprocessor/traits/decl.hpp 2011-12-16 13:56:12 EST (Fri, 16 Dec 2011)
@@ -4,32 +4,29 @@
 // License, Version 1.0 (see accompanying file LICENSE_1_0.txt or a
 // copy at http://www.boost.org/LICENSE_1_0.txt).
 
-#ifndef BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_HPP_
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_HPP_
+#ifndef BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HPP_
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS_HPP_
 
-#include "parse_params_/is_void.hpp"
-#include "parse_params_/seq.hpp"
-#include "parsed_params_/nil.hpp"
+#include <boost/closure/aux_/preprocessor/traits/decl_sign_/is_void.hpp>
+#include <boost/closure/aux_/preprocessor/traits/decl_sign_/seq.hpp>
+#include <boost/closure/aux_/preprocessor/triats/decl_/nil.hpp>
 #include <boost/preprocessor/control/iif.hpp>
-
-// PRIVATE //
-
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_NONE_(unused) \
- BOOST_LOCAL_AUX_PP_SIGN_PARSED_PARAMS_NIL
+#include <boost/preprocessor/tuple/eat.hpp>
 
 // PUBLIC //
 
-// parenthesized_params: Empty ``, or `void`, or `(void)` for no params
-// Or, `{([auto | register] param_type param_name)[(default default_value)]
-// | ([const] bind [&] bind_name}+` where `bind_name` can be `this` (but not
-// `&this` as usual in C++).
-#define BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS(parenthesized_params) \
- BOOST_PP_IIF(BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_IS_VOID( \
- parenthesized_params), \
- BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_NONE_ \
+// declaration_seq can be empty ``, or `void`, or `(void)` for no params.
+// Or, `{([auto | register] param_type param_name)[(default default_value)]
+// | ([const] bind [&] bind_name)}+ [(return result_type)]` where `bind_name`
+// can be `this_` (but not `&this_` as usual in C++).
+#define BOOST_CLOSURE_AUX_PP_DECL_TRAITS(declaration_seq) \
+ BOOST_PP_IIF(BOOST_CLOSURE_AUX_PP_DECL_TRAITS_SIGN_IS_VOID( \
+ declaration_seq), \
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_NIL \
+ BOOST_PP_TUPLE_EAT(1) \
     , \
- BOOST_LOCAL_AUX_PP_SIGN_PARSE_PARAMS_SEQ \
- )(parenthesized_params)
+ BOOST_CLOSURE_AUX_PP_DECL_TRAITS_SIGN_SEQ \
+ )(declaration_seq)
 
 #endif // #include guard
 

Copied: sandbox/closure/boost/closure/aux_/preprocessor/traits/decl_any_bind.hpp (from r75985, /sandbox/closure/boost/closure/aux_/preprocessor/traits/params_any_bind.hpp)
==============================================================================